@@ -125,7 +125,7 @@ std::shared_ptr<JSONCatalog> JSONCatalog::Open(const wxString& filename)
 
         auto cat = CreateForJSON(std::move(data), ext);
         if (!cat)
-            throw JSONUnrecognizedFileException();
+            BOOST_THROW_EXCEPTION(JSONUnrecognizedFileException());
 
         f.clear();
         f.seekg(0, std::ios::beg);
@@ -137,7 +137,7 @@ std::shared_ptr<JSONCatalog> JSONCatalog::Open(const wxString& filename)
     }
     catch (json::exception& e)
     {
-        throw JSONFileException(wxString::Format(_("Reading file content failed with the following error: %s"), e.what()));
+        BOOST_THROW_EXCEPTION(JSONFileException(wxString::Format(_("Reading file content failed with the following error: %s"), e.what())));
     }
 }
 
@@ -234,7 +234,7 @@ public:
         ParseSubtree(id, m_doc, "");
 
         if (m_items.empty())
-            throw JSONUnrecognizedFileException();
+            BOOST_THROW_EXCEPTION(JSONUnrecognizedFileException());
     }
 
 private:
@@ -253,7 +253,7 @@ private:
             }
             else
             {
-                throw JSONUnrecognizedFileException();
+                BOOST_THROW_EXCEPTION(JSONUnrecognizedFileException());
             }
         }
     }
@@ -353,7 +353,7 @@ private:
             }
             else
             {
-                throw JSONUnrecognizedFileException();
+                BOOST_THROW_EXCEPTION(JSONUnrecognizedFileException());
             }
         }
     }
@@ -387,13 +387,13 @@ public:
         {
             auto& val = el.value();
             if (!val.is_object())
-                throw JSONUnrecognizedFileException();
+                BOOST_THROW_EXCEPTION(JSONUnrecognizedFileException());
 
             m_items.push_back(std::make_shared<Item>(++id, el.key(), val));
         }
 
         if (m_items.empty())
-            throw JSONUnrecognizedFileException();
+            BOOST_THROW_EXCEPTION(JSONUnrecognizedFileException());
     }
 
 protected:
